/* -*-c-*-
 *
 * $Id$
 *
 * Key management error codes
 *
 * (c) 2004 Straylight/Edgeware
 */

/*----- Licensing notice --------------------------------------------------* 
 *
 * This file is part of Catacomb.
 *
 * Catacomb is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Library General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 * 
 * Catacomb is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 * 
 * You should have received a copy of the GNU Library General Public
 * License along with Catacomb; if not, write to the Free
 * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
 * MA 02111-1307, USA.
 */

#ifndef CATACOMB_KEY_ERROR_H
#define CATACOMB_KEY_ERROR_H

#ifdef __cplusplus
  extern "C" {
#endif

/*----- Error codes -------------------------------------------------------*/

enum {
  KERR_OK = 0,				/* No error */
  KERR_BADTAG = -1,			/* Malformed tag string */
  KERR_BADTYPE = -2,			/* Malformed type string */
  KERR_BADCOMMENT = -3,			/* Malformed comment string */
  KERR_DUPID = -4,			/* Duplicate keyid */
  KERR_DUPTAG = -5,			/* Duplicate key tag string */
  KERR_READONLY = -6,			/* Key file is read-only */
  KERR_WILLEXPIRE = -7,			/* Key will eventually expire */
  KERR_EXPIRED = -8,			/* Key has already expired */
  KERR_BADFLAGS = -9,			/* Error in flags string */
  KERR_BADPASS = -10,			/* Error decrypting locked key */
  KERR_WRONGTYPE = -11,			/* Key has incorrect type */
  KERR_NOTFOUND = -12,			/* Key couldn't be found */
  KERR_BADATTR = -13,			/* Malformed attribute name */
  KERR_MALFORMED = -14,			/* Key data is malformed */
  KERR_IO = -15,			/* I/O error of some kind */
  KERR_MAX = -16			/* Not useful */
};

/*----- Functions provided ------------------------------------------------*/

/* --- @key_strerror@ --- *
 *
 * Arguments:	@int err@ = error code from @key_new@
 *
 * Returns:	Pointer to error string.
 *
 * Use:		Translates a @KERR@ error code into a human-readable string.
 */

extern const char *key_strerror(int /*err*/);

/*----- That's all, folks -------------------------------------------------*/

#ifdef __cplusplus
  }
#endif

#endif
